@@ -15,16 +15,12 @@
 
 from collections import defaultdict
 from enum import IntEnum
+from time import perf_counter
 
 import attr
 
 from hypothesis.errors import Frozen, InvalidArgument, StopTest
-from hypothesis.internal.compat import (
-    benchmark_time,
-    bit_length,
-    int_from_bytes,
-    int_to_bytes,
-)
+from hypothesis.internal.compat import bit_length, int_from_bytes, int_to_bytes
 from hypothesis.internal.conjecture.junkdrawer import IntList, uniform
 from hypothesis.internal.conjecture.utils import calc_label_from_name
 from hypothesis.internal.escalation import mark_for_escalation
@@ -778,7 +774,7 @@ class ConjectureData:
         global global_test_counter
         self.testcounter = global_test_counter
         global_test_counter += 1
-        self.start_time = benchmark_time()
+        self.start_time = perf_counter()
         self.events = set()
         self.forced_indices = set()
         self.interesting_origin = None
@@ -870,7 +866,7 @@ class ConjectureData:
             # can be almost arbitrarily slow.  In cases like characters() and text()
             # where we cache something expensive, this led to Flaky deadline errors!
             # See https://github.com/HypothesisWorks/hypothesis/issues/2108
-            start_time = benchmark_time()
+            start_time = perf_counter()
 
         strategy.validate()
 
@@ -892,7 +888,7 @@ class ConjectureData:
                     try:
                         return strategy.do_draw(self)
                     finally:
-                        self.draw_times.append(benchmark_time() - start_time)
+                        self.draw_times.append(perf_counter() - start_time)
                 except BaseException as e:
                     mark_for_escalation(e)
                     raise
@@ -971,7 +967,7 @@ class ConjectureData:
         if self.frozen:
             assert isinstance(self.buffer, bytes)
             return
-        self.finish_time = benchmark_time()
+        self.finish_time = perf_counter()
         assert len(self.buffer) == self.index
 
         # Always finish by closing all remaining examples so that we have a
